"use client";
import { getAssignmentList } from "@/app/lib/assignment/action";
import { Box } from "@chakra-ui/react";
import CardList from "./components/card-list";
import { useEffect, useState, useCallback } from "react";
import { getStorage, setStorage } from "@/utils/navigation";

const Page = () => {
  const [data, setData] = useState([]);
  const [loading, setLoading] = useState(true);
  const [storedDraftConsumers, setStoredDraftConsumers] = useState([]);
  const [storedDraftDcs, setStoredDraftDcs] = useState([]);
  const [storedDraftKycs, setStoredDraftKycs] = useState([]);

  // Optimized sync handler with useCallback
  const handleSync = useCallback(async () => {
    setLoading(true);
    try {
      const res = await getAssignmentList({ pagination: "false" });
      const updatedData = {
        last_sync_at: new Date().toISOString(),
        data: res?.data || [],
      };

      setData(updatedData.data);
      setStorage("assignments", updatedData);
    } catch (error) {
      console.error("Error syncing assignments:", error);
    } finally {
      setLoading(false);
    }
  }, []);

  // Optimized data fetching
  useEffect(() => {
    const fetchData = async () => {
      setLoading(true);
      try {
        const storedData = await getStorage("assignments");

        // Check if stored data is stale (use milliseconds for comparison)
        const isDataStale =
          !storedData?.last_sync_at ||
          Date.now() - new Date(storedData.last_sync_at).getTime() > 86400000;

        if (storedData?.data && !isDataStale) {
          setData(storedData.data);
        } else {
          await handleSync();
        }
      } catch (error) {
        console.error("Error fetching assignments:", error);
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, []);

  useEffect(() => {
    const loadDraftConsumers = async () => {
      const storedData = (await getStorage("draft-consumers")) ?? [];
      if (storedData) {
        setStoredDraftConsumers(storedData);
      }
    };
    loadDraftConsumers();
  }, []);

  useEffect(() => {
    const loadDraftDcs = async () => {
      const storedData = (await getStorage("draft-dcs")) ?? [];
      if (storedData) {
        setStoredDraftDcs(storedData);
      }
    };
    loadDraftDcs();
  }, []);

  useEffect(() => {
    const loadDraftKycs = async () => {
      const storedData = (await getStorage("draft-kycs")) ?? [];
      if (storedData) {
        setStoredDraftKycs(storedData);
      }
    };
    loadDraftKycs();
  }, []);

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      <CardList
        data={data}
        draftDetails={[...storedDraftConsumers, ...storedDraftDcs, ...storedDraftKycs]} // Combine drafts
        isLoading={loading}
        handleSync={handleSync}
      />
    </Box>
  );
};

export default Page;
